package com.jiuqi.util.inifile;

import com.jiuqi.util.Stream;
import com.jiuqi.util.StreamException;

public final class StreamIniBuffer extends IniBuffer {
   private Stream stream;
   private int cursor;

   public StreamIniBuffer(Stream aStream) {
      this.stream = aStream;
   }

   public int getEntry() {
      return this.cursor;
   }

   public void gotoCursor() {
      try {
         this.stream.setPosition((long)this.cursor);
      } catch (Exception var2) {
         Exception ex = var2;
         ex.printStackTrace();
      }

   }

   public void writeEntry() {
      try {
         this.stream.setPosition(this.stream.getSize());
         this.stream.writeInt(this.cursor);
         this.stream.writeString("BINI");
      } catch (Exception var2) {
         Exception ex = var2;
         ex.printStackTrace();
      }

   }

   public boolean gotoEntry(boolean isRead) {
      boolean ret = false;

      try {
         if (isRead) {
            this.cursor = 0;
            if (this.stream.getSize() < 8L) {
               return ret;
            }

            this.stream.setPosition(this.stream.getSize() - 4L);
            String s = this.stream.readString(4);
            if (s.equals("BINI")) {
               this.stream.setPosition(this.stream.getSize() - 8L);
               this.cursor = this.stream.readInt();
               this.stream.setPosition((long)this.cursor);
               return true;
            }
         } else {
            this.stream.setPosition((long)this.cursor);
            ret = true;
         }
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public void writeInfoBoolean(boolean value) {
      try {
         this.stream.writeBool(value);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

   }

   public void writeInfoDouble(double value) {
      try {
         this.stream.writeDouble(value);
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

   }

   public void writeInfoInteger(int value) {
      try {
         this.stream.writeInt(value);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

   }

   public void writeInfoLong(long value) {
      try {
         this.stream.writeLong(value);
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

   }

   public void writeInfoString(String value) {
      try {
         if (value == null) {
            this.stream.write((byte)0);
            return;
         }

         byte[] b = this.stream.encodeString(value);
         byte sl = (byte)b.length;
         this.stream.write(sl);
         this.stream.write(b, 0, b.length);
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

   }

   public void writeInfoByte(byte value) {
      try {
         this.stream.write(value);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

   }

   public boolean readInfoBoolean() {
      boolean ret = false;

      try {
         ret = this.stream.readBool();
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

      return ret;
   }

   public double readInfoDouble() {
      double ret = 0.0;

      try {
         ret = this.stream.readDouble();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public int readInfoInteger() {
      int ret = 0;

      try {
         ret = this.stream.readInt();
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

      return ret;
   }

   public long readInfoLong() {
      long ret = 0L;

      try {
         ret = this.stream.readLong();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public String readInfoString() {
      String ret = null;

      try {
         byte sl = this.stream.read();
         ret = this.stream.readString(sl);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

      return ret;
   }

   public byte readInfoByte() {
      byte ret = 0;

      try {
         ret = this.stream.read();
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeBoolean(boolean value) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.writeBool(value);
         ++this.cursor;
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeDouble(double value) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.writeDouble(value);
         this.cursor = (int)this.stream.getPosition();
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeInteger(int value) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.writeInt(value);
         this.cursor = (int)this.stream.getPosition();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeLong(long value) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.writeLong(value);
         this.cursor = (int)this.stream.getPosition();
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeString(String value) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.writeStringWithSize(value);
         this.cursor = (int)this.stream.getPosition();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public boolean readBoolean(int position) {
      boolean ret = false;

      try {
         this.stream.setPosition((long)position);
         ret = this.stream.readBool();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public double readDouble(int position) {
      double ret = 0.0;

      try {
         this.stream.setPosition((long)position);
         ret = this.stream.readDouble();
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public int readInteger(int position) {
      int ret = 0;

      try {
         this.stream.setPosition((long)position);
         ret = this.stream.readInt();
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public long readLong(int position) {
      long ret = 0L;

      try {
         this.stream.setPosition((long)position);
         ret = this.stream.readLong();
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public String readString(int position) {
      String ret = null;

      try {
         this.stream.setPosition((long)position);
         int sl = this.stream.readInt();
         ret = this.stream.readString(sl);
      } catch (Exception var4) {
         Exception ex = var4;
         ex.printStackTrace();
      }

      return ret;
   }

   public int writeStream(Stream aStream, int size) {
      int ret = this.cursor;

      try {
         this.stream.setPosition((long)this.cursor);
         this.stream.copyFrom(aStream, (long)size);
         this.cursor = (int)this.stream.getPosition();
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

      return ret;
   }

   public void readStream(Stream aStream, int position, int size) {
      try {
         this.stream.setPosition((long)position);
         aStream.copyFrom(this.stream, (long)size);
      } catch (Exception var5) {
         Exception ex = var5;
         ex.printStackTrace();
      }

   }

   public void loadFromStream(Stream aStream) {
      try {
         this.stream.setSize(aStream.getSize());
         this.stream.setPosition(0L);
         this.stream.copyFrom(aStream, 0L);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

   }

   public void replaceStream(Stream aStream) {
      this.stream = aStream;
   }

   public void saveToStream(Stream aStream) {
      try {
         aStream.setSize(this.stream.getSize());
         aStream.setPosition(0L);
         aStream.copyFrom(this.stream, 0L);
      } catch (Exception var3) {
         Exception ex = var3;
         ex.printStackTrace();
      }

   }

   public static boolean verify(Stream stream) {
      try {
         long origin = stream.getPosition();

         boolean var5;
         try {
            StreamIniBuffer buffer = new StreamIniBuffer(stream);
            var5 = buffer.verify();
         } finally {
            stream.setPosition(origin);
         }

         return var5;
      } catch (StreamException var9) {
         StreamException e = var9;
         e.printStackTrace();
         return false;
      }
   }
}
